clear
set more off
cd "/Users/nketel1/Dropbox/Sunk Cost/data/
//cd "/Users/hessel/Dropbox/Sunk Cost/data/

//load dataset
use work


//Remove part-time students from sample
drop if leeftijd>26&leeftijd!=.
drop if inkomen>1200&inkomen!=.

//Generate indicator if one of the control variables is missing 
g missing=(vrouw==.|leeftijd==.|inkomen==.|maxbedr_frac==.|bron_ouders==.|tijd_studie==.|eerstepoging==.|kans_zonder==.)

//Generate indicators for the three different hypotheses 
g hyp1=niks
g hyp2=(niks==1|weinig==1)
g hyp3=(niks==1|weinig==1|nietalles==1)

label var hyp1 "Paying matters"
label var hyp2 "Amount matters"
label var hyp3 "Discount matters"

//TABLE I: 
//Create table with summary statistics
local quest1 "vrouw leeftijd inkomen econ tijd_studie tijd_vak eerstepoging maxbedr_frac kans_zonder kans_met bron_ouders"
local quest2 "sunk_cost eindoordeel tijd_vak_realisatie kans_achteraf"
eststo: estpost summarize `quest1' `quest2'  missing
bys treatment: eststo:  estpost summarize `quest1' `quest2' missing
eststo clear

matrix X = J(`=wordcount("`quest1' `quest2' missing")+2', 1, 0)
local i 0
foreach x in `quest1' `quest2'  {
    local i `i'+1
    kwallis `x', by(treatment)
    matrix X[`i', 1] = chi2tail(r(df), r(chi2))
}
mat list X, f(%9.2f) noh non


//Define outcome variables and control variables
global treatvar "niks weinig nietalles"
global hypvar "hyp1 hyp2 hyp3"
global outcomevar "geslaagd eindcijfer tijd_vak_realisatie"
global attvar "always_pres frac_aanw"
global classvar "les2_aanw les3_aanw pres_lastclass"
global controls "vrouw leeftijd inkomen maxbedr_frac bron_ouders tijd_studie eerstepoging kans_zonder"
global controls_noink "vrouw leeftijd maxbedr_frac bron_ouders tijd_studie eerstepoging kans_zonder"

//In all regressions, we first use dummies for every treatment, and then use dummies for every hypothesis

//TABLE 2: 
//Column 1&3: Attendance, no controls 
foreach i in $attvar {
	foreach j in $hypvar {
	qui reg `i' `j' if missing==0, robust cluster(sessie)
	eststo `j'`i'
	qui reg `i' $treatvar if missing==0, robust cluster(sessie)
	eststo treat`i'
	qui reg `i' frac_korting if missing==0, robust cluster(sessie)
	eststo cont`i'
		}
	}
esttab treat*, se ar2 star(* 0.10 ** 0.05 *** 0.01) b(%9.2f) label keep($treatvar)
esttab hyp1*, se ar2 star(* 0.10 ** 0.05 *** 0.01) b(%9.2f) label keep(hyp1)
esttab hyp2*, se ar2 star(* 0.10 ** 0.05 *** 0.01) b(%9.2f) label keep(hyp2)
esttab hyp3*, se ar2 star(* 0.10 ** 0.05 *** 0.01) b(%9.2f) label keep(hyp3)
esttab cont*, se ar2 star(* 0.10 ** 0.05 *** 0.01) b(%9.2f) label keep(frac_korting)

est clear

//Column 2&4: Attendance, controls
foreach i in $attvar {
	foreach j in $hypvar {
	qui reg `i' `j' $controls i.vakcode, robust cluster(sessie)
	eststo `j'`i'
	qui reg `i' $treatvar $controls i.vakcode, robust cluster(sessie)
	eststo treat`i'
	qui reg `i' frac_korting $controls i.vakcode, robust cluster(sessie)
	eststo cont`i'
		}
	}
esttab treat*, se ar2 star(* 0.10 ** 0.05 *** 0.01) b(%9.2f) label keep($treatvar)	
esttab hyp1*, se ar2 star(* 0.10 ** 0.05 *** 0.01) b(%9.2f) label keep(hyp1)
esttab hyp2*, se ar2 star(* 0.10 ** 0.05 *** 0.01) b(%9.2f) label keep(hyp2)
esttab hyp3*, se ar2 star(* 0.10 ** 0.05 *** 0.01) b(%9.2f) label keep(hyp3)
esttab cont*, se ar2 star(* 0.10 ** 0.05 *** 0.01) b(%9.2f) label keep(frac_korting)
est clear


//TABLE 3 AND TABLE B2
//Attendance by session and study performance: Without controls (Table B2)
foreach i in $classvar $outcomevar {
	foreach j in $hypvar {
		qui reg `i' `j' if missing==0, robust cluster(sessie)
		eststo `j'`i'
		qui reg `i' $treatvar if missing==0, robust cluster(sessie)
		eststo treat`i'
		qui reg `i' frac_korting if missing==0, robust cluster(sessie)
		eststo cont`i'
		}
	}
esttab treat*, se ar2 star(* 0.10 ** 0.05 *** 0.01) b(%9.2f) label keep($treatvar)	
esttab hyp1*, se ar2 star(* 0.10 ** 0.05 *** 0.01) b(%9.2f) label keep(hyp1)
esttab hyp2*, se ar2 star(* 0.10 ** 0.05 *** 0.01) b(%9.2f) label keep(hyp2)
esttab hyp3*, se ar2 star(* 0.10 ** 0.05 *** 0.01) b(%9.2f) label keep(hyp3)
esttab cont*, se ar2 star(* 0.10 ** 0.05 *** 0.01) b(%9.2f) label keep(frac_korting)
est clear

//Attendance by session and study performance: With controls (Table 3)
foreach i in $classvar $outcomevar {
	foreach j in $hypvar {
		qui reg `i' `j' $controls i.vakcode, robust cluster(sessie)
		eststo `j'`i'
		qui reg `i' $treatvar $controls i.vakcode, robust cluster(sessie)
		eststo treat`i'
		qui reg `i' frac_korting $controls i.vakcode, robust cluster(sessie)
		eststo cont`i'
		}
	}
esttab treat*, se ar2 star(* 0.10 ** 0.05 *** 0.01) b(%9.2f) label keep($treatvar)
esttab hyp1*, se ar2 star(* 0.10 ** 0.05 *** 0.01) b(%9.2f) label keep(hyp1)
esttab hyp2*, se ar2 star(* 0.10 ** 0.05 *** 0.01) b(%9.2f) label keep(hyp2)
esttab hyp3*, se ar2 star(* 0.10 ** 0.05 *** 0.01) b(%9.2f) label keep(hyp3)
esttab cont*, se ar2 star(* 0.10 ** 0.05 *** 0.01) b(%9.2f) label keep(frac_korting)
est clear

//TABLE 4&5: HETEROGENEOUS EFFECTS BY PARENTS PAYING AND STUDENT INCOME

//Parents paid, attendance and performance, controls, interaction 
//(table 4 columns 1a/1b, 3a/3b, table 5 columns 1a/1b, 3a/3b)
foreach i in $attvar $outcomevar {
	qui reg `i' ib(last).treatment i.bron_ouders i.bron_ouders#ib(last).treatment $controls i.vakcode, robust cluster(sessie)
	eststo treat`i'
	//"Parents paid, effect on: outcome variables
	lincom 1.treatment + 1.bron_ouders#1.treatment
	lincom 2.treatment + 1.bron_ouders#2.treatment
	lincom 3.treatment + 1.bron_ouders#3.treatment
	foreach j in $hypvar {
	qui reg `i' i.`j' i.bron_ouders i.bron_ouders#i.`j' $controls i.vakcode, robust cluster(sessie)
	eststo `j'`i'
	des `i'
	lincom 1.`j' + 1.bron_ouders#1.`j'
		}
	qui reg `i' frac_korting $controls i.vakcode i.bron_ouders i.bron_ouders#c.frac_korting, robust cluster(sessie)
	eststo cont`i'
	des `i'
	lincom 	c.frac_korting + c.frac_korting#1.bron_ouders
	}
//Parents did not pay, effect on outcome variables
esttab treat*, se ar2 star(* 0.10 ** 0.05 *** 0.01) b(%9.2f) label keep(1.treatment 2.treatment 3.treatment)
esttab hyp1*, se ar2 star(* 0.10 ** 0.05 *** 0.01) b(%9.2f) label keep(1.hyp1)
esttab hyp2*, se ar2 star(* 0.10 ** 0.05 *** 0.01) b(%9.2f) label keep(1.hyp2)
esttab hyp3*, se ar2 star(* 0.10 ** 0.05 *** 0.01) b(%9.2f) label keep(1.hyp3)
esttab cont*, se ar2 star(* 0.10 ** 0.05 *** 0.01) b(%9.2f) label keep(frac_korting)
est clear

//Income above median, attendance and performance, controls, interaction 
//(table 4 columns 2a/2b, 4a/4b, table 5 columns 2a/2b, 4a/4b)
g ink_bov_med=1 if inkomen>=550&inkomen!=.
replace ink_bov_med=0 if inkomen<550&inkomen!=.

foreach i in $attvar $outcomevar{
	qui reg `i' ib(last).treatment i.ink_bov_med i.ink_bov_med#ib(last).treatment $controls i.vakcode, robust cluster(sessie)
	eststo treat`i'
	des `i'
	//Income above median, effects
	lincom 1.treatment + 1.ink_bov_med#1.treatment
	lincom 2.treatment + 1.ink_bov_med#2.treatment
	lincom 3.treatment + 1.ink_bov_med#3.treatment
	foreach j in $hypvar {
	qui reg `i' i.`j' i.ink_bov_med i.ink_bov_med#i.`j' $controls i.vakcode, robust cluster(sessie)
	eststo `j'`i'
	des `i'
	lincom 1.`j' + 1.ink_bov_med#1.`j'
		}
	qui reg `i' frac_korting $controls i.vakcode i.ink_bov_med i.ink_bov_med#c.frac_korting, robust cluster(sessie)
	eststo cont`i'
	des `i'
	lincom 	c.frac_korting + c.frac_korting#1.ink_bov_med
	}
//Income below median, effects	
esttab treat*, se ar2 star(* 0.10 ** 0.05 *** 0.01) b(%9.2f) label keep(1.treatment 2.treatment 3.treatment)
esttab hyp1*, se ar2 star(* 0.10 ** 0.05 *** 0.01) b(%9.2f) label keep(1.hyp1)
esttab hyp2*, se ar2 star(* 0.10 ** 0.05 *** 0.01) b(%9.2f) label keep(1.hyp2)
esttab hyp3*, se ar2 star(* 0.10 ** 0.05 *** 0.01) b(%9.2f) label keep(1.hyp3)
esttab cont*, se ar2 star(* 0.10 ** 0.05 *** 0.01) b(%9.2f) label keep(frac_korting)
est clear


//TABLE 6: ATTENDANCE BY SUNK-COST PRONENESS
//Attendance, controls, sunk-cost prone, interaction (columns 1&2)
foreach i in $attvar {
	qui reg `i' ib(last).treatment i.sunk_cost i.sunk_cost#ib(last).treatment $controls i.vakcode if missing==0, robust cluster(sessie)
	eststo treat`i'
	des `i'
	//sunk-cost prone, effects
	lincom 1.treatment + 1.sunk_cost#1.treatment
	lincom 2.treatment + 1.sunk_cost#2.treatment
	lincom 3.treatment + 1.sunk_cost#3.treatment
	foreach j in $hypvar {
	qui reg `i' i.`j' i.sunk_cost i.sunk_cost#i.`j'  i.vakcode $controls if missing==0, robust cluster(sessie)
	eststo `j'`i'
	des `i'
	lincom 1.`j' + 1.sunk_cost#1.`j'
		}
	qui reg `i' frac_korting i.vakcode i.sunk_cost i.sunk_cost#c.frac_korting $controls if missing==0, robust cluster(sessie)
	eststo cont`i'
	des `i'
	lincom 	c.frac_korting + c.frac_korting#1.sunk_cost
	}
//Not sunk-cost prone, effects	
esttab treat*, se ar2 star(* 0.10 ** 0.05 *** 0.01) b(%9.2f) label keep(1.treatment 2.treatment 3.treatment)
esttab hyp1*, se ar2 star(* 0.10 ** 0.05 *** 0.01) b(%9.2f) label keep(1.hyp1)
esttab hyp2*, se ar2 star(* 0.10 ** 0.05 *** 0.01) b(%9.2f) label keep(1.hyp2)
esttab hyp3*, se ar2 star(* 0.10 ** 0.05 *** 0.01) b(%9.2f) label keep(1.hyp3)
esttab cont*, se ar2 star(* 0.10 ** 0.05 *** 0.01) b(%9.2f) label keep(frac_korting)
est clear

//Column 3
foreach i in sunk_cost {
	foreach j in $hypvar {
	qui reg `i' `j' $controls i.vakcode, robust cluster(sessie)
	eststo `j'`i'
	qui reg `i' $treatvar $controls i.vakcode, robust cluster(sessie)
	eststo treat`i'
	qui reg `i' frac_korting $controls i.vakcode, robust cluster(sessie)
	eststo cont`i'
		}
	}
esttab treat*, se ar2 star(* 0.10 ** 0.05 *** 0.01) b(%9.2f) label keep($treatvar)	
esttab hyp1*, se ar2 star(* 0.10 ** 0.05 *** 0.01) b(%9.2f) label keep(hyp1)
esttab hyp2*, se ar2 star(* 0.10 ** 0.05 *** 0.01) b(%9.2f) label keep(hyp2)
esttab hyp3*, se ar2 star(* 0.10 ** 0.05 *** 0.01) b(%9.2f) label keep(hyp3)
esttab cont*, se ar2 star(* 0.10 ** 0.05 *** 0.01) b(%9.2f) label keep(frac_korting)
est clear

//TABLE 7&8: ATTENDANCE BY SESSION AND PERFORMANCE FOR SUNK-COST PRONE STUDENTES
//Attendance and performance, controls, sunk-cost prone, interaction
foreach i in $classvar $outcomevar {
	qui reg `i' ib(last).treatment i.sunk_cost i.sunk_cost#ib(last).treatment $controls i.vakcode, robust cluster(sessie)
	eststo treat`i'
	des `i'
	//sunk-cost prone, effects
	lincom 1.treatment + 1.sunk_cost#1.treatment
	lincom 2.treatment + 1.sunk_cost#2.treatment
	lincom 3.treatment + 1.sunk_cost#3.treatment
	foreach j in $hypvar {
	qui reg `i' i.`j' i.sunk_cost i.sunk_cost#i.`j' $controls i.vakcode, robust cluster(sessie)
	eststo `j'`i'
	des `i'
	lincom 1.`j' + 1.sunk_cost#1.`j'
		}
	qui reg `i' frac_korting $controls i.vakcode i.sunk_cost i.sunk_cost#c.frac_korting, robust cluster(sessie)
	eststo cont`i'
	des `i'
	lincom 	c.frac_korting + c.frac_korting#1.sunk_cost
	}
//not sunk-cost prone, effects
esttab treat*, se ar2 star(* 0.10 ** 0.05 *** 0.01) b(%9.2f) label keep(1.treatment 2.treatment 3.treatment)
esttab hyp1*, se ar2 star(* 0.10 ** 0.05 *** 0.01) b(%9.2f) label keep(1.hyp1)
esttab hyp2*, se ar2 star(* 0.10 ** 0.05 *** 0.01) b(%9.2f) label keep(1.hyp2)
esttab hyp3*, se ar2 star(* 0.10 ** 0.05 *** 0.01) b(%9.2f) label keep(1.hyp3)
esttab cont*, se ar2 star(* 0.10 ** 0.05 *** 0.01) b(%9.2f) label keep(frac_korting)
est clear


//TABLE 9: CHARACTERIZING SUNK-COST PRONE STUDENTS
//Generate table with explanatory variables for sunk-cost prone and parents paid.
reg sunk_cost vrouw leeftijd  if missing==0, r
reg sunk_cost vrouw leeftijd inkomen econ if missing==0, r
reg sunk_cost quest_phone quest_mail if missing==0, r
reg sunk_cost vrouw leeftijd inkomen econ tijd_studie eerstepoging maxbedr_frac  kans_zonder bron_ouders quest_phone quest_mail if missing==0, r



//TABLE B1: METHOD OF RESPONSE
//Response, controls (column 1)
foreach i in response {
	foreach j in $hypvar {
	qui reg `i' `j' $controls i.vakcode, robust cluster(sessie)
	eststo `j'`i'
	qui reg `i' $treatvar $controls i.vakcode, robust cluster(sessie)
	eststo treat`i'
	qui reg `i' frac_korting $controls i.vakcode, robust cluster(sessie)
	eststo cont`i'
		}
	}
esttab treat*, se ar2 star(* 0.10 ** 0.05 *** 0.01) b(%9.2f) label keep($treatvar)	
esttab hyp1*, se ar2 star(* 0.10 ** 0.05 *** 0.01) b(%9.2f) label keep(hyp1)
esttab hyp2*, se ar2 star(* 0.10 ** 0.05 *** 0.01) b(%9.2f) label keep(hyp2)
esttab hyp3*, se ar2 star(* 0.10 ** 0.05 *** 0.01) b(%9.2f) label keep(hyp3)
esttab cont*, se ar2 star(* 0.10 ** 0.05 *** 0.01) b(%9.2f) label keep(frac_korting)

est clear

//Method of response, controls (column 2&3)
foreach i in quest_mail quest_phone {
	foreach j in $hypvar {
	qui reg `i' `j' $controls i.vakcode if missing==0 & sunk_cost!=., robust cluster(sessie)
	eststo `j'`i'
	qui reg `i' $treatvar $controls i.vakcode if missing==0 & sunk_cost!=., robust cluster(sessie)
	eststo treat`i'
	qui reg `i' frac_korting $controls i.vakcode if missing==0 & sunk_cost!=., robust cluster(sessie)
	eststo cont`i'
		}
	}
esttab treat*, se ar2 star(* 0.10 ** 0.05 *** 0.01) b(%9.2f) label keep($treatvar)	
esttab hyp1*, se ar2 star(* 0.10 ** 0.05 *** 0.01) b(%9.2f) label keep(hyp1)
esttab hyp2*, se ar2 star(* 0.10 ** 0.05 *** 0.01) b(%9.2f) label keep(hyp2)
esttab hyp3*, se ar2 star(* 0.10 ** 0.05 *** 0.01) b(%9.2f) label keep(hyp3)
esttab cont*, se ar2 star(* 0.10 ** 0.05 *** 0.01) b(%9.2f) label keep(frac_korting)

est clear

//TABLE B3: EFFECTS OF TREATMENTS ON ATTENDANCE, BALANCED SAMPLE
//Columns 1&3
foreach i in $attvar {
	foreach j in $hypvar {
	qui reg `i' `j' $controls i.vakcode if sunk_cost!=., robust cluster(sessie)
	eststo `j'`i'
	qui reg `i' $treatvar $controls i.vakcode if sunk_cost!=., robust cluster(sessie)
	eststo treat`i'
	qui reg `i' frac_korting $controls i.vakcode if sunk_cost!=., robust cluster(sessie)
	eststo cont`i'
		}
	}
esttab treat*, se ar2 star(* 0.10 ** 0.05 *** 0.01) b(%9.2f) label keep($treatvar)	
esttab hyp1*, se ar2 star(* 0.10 ** 0.05 *** 0.01) b(%9.2f) label keep(hyp1)
esttab hyp2*, se ar2 star(* 0.10 ** 0.05 *** 0.01) b(%9.2f) label keep(hyp2)
esttab hyp3*, se ar2 star(* 0.10 ** 0.05 *** 0.01) b(%9.2f) label keep(hyp3)
esttab cont*, se ar2 star(* 0.10 ** 0.05 *** 0.01) b(%9.2f) label keep(frac_korting)
est clear


